@@ -10,7 +10,7 @@ import requests
 from AnyQt.QtCore import Qt, QModelIndex, QItemSelection, Signal, \
     QItemSelectionModel
 from AnyQt.QtGui import QDropEvent, QStandardItemModel, QStandardItem, \
-    QPainter, QColor, QPalette, QDragEnterEvent, QDragLeaveEvent
+    QPainter, QColor, QPalette, QDragEnterEvent, QDragLeaveEvent, QKeyEvent
 from AnyQt.QtWidgets import QWidget, QAction, QVBoxLayout, QTreeView, QMenu, \
     QToolButton, QGroupBox, QListView, QSizePolicy, QStyledItemDelegate, \
     QStyleOptionViewItem, QLineEdit, QFileDialog, QApplication, QDialog, \
@@ -104,7 +104,8 @@ def _tree_to_html(tree: Dict) -> str:
 def _onto_to_tree(thing: Thing, world: World) -> Dict:
     tree = {}
     for cl in list(thing.subclasses(world=world)):
-        tree[cl.name] = _onto_to_tree(cl, world)
+        label = (cl.label.first() or cl.name).replace("\n", " ").strip()
+        tree[label] = _onto_to_tree(cl, world)
     return tree
 
 
@@ -356,6 +357,13 @@ class EditableTreeView(QWidget):
         self._enable_undo_redo()
         self.dataChanged.emit()
 
+    def keyPressEvent(self, event: QKeyEvent):
+        """Delete element with delete or backspace key"""
+        if event.key() == Qt.Key_Delete or event.key() == Qt.Key_Backspace:
+            self.__on_remove_recursive()
+        else:
+            super().keyPressEvent(event)
+
 
 class Ontology:
     NotModified, Modified = range(2)
